# intro.sql
* **Authored-By**: _Some Chap or Lass_
* **Authored-On**: _Some Day or Year_


**Impetus**: *SQL is older than time and isn't going anywhere; might we allow a simple markup syntax?*

## (1) create table~sample_table; DDL
* **Description**: _This is an example statement description_

```sql
create or replace table sample_table (
	col1 number(18,0),
	col2 number(18,0)
);
```
